Title: [188207] trunk/Tools
- Revision
- 188207
- Author
- [email protected]
- Date
- 2015-08-10 01:24:59 -0700 (Mon, 10 Aug 2015)
Log Message
[GTK] Test /webkit2/WebKitWebView/submit-form is flaky
https://bugs.webkit.org/show_bug.cgi?id=147727
Reviewed by Sergio Villar Senin.
I think it was not this test in particular, but
/webkit2/WebKitWebView/custom-charset that is affecting the
others. This is because changing the encoding reloads the page,
but we don't wait for the page to be reloaded, so when the test
finishes and other test starts the web process is still reloading
the page.
* Scripts/run-gtk-tests:
(TestRunner): Unskip /webkit2/WebKitWebView/submit-form.
* TestWebKitAPI/Tests/WebKit2Gtk/TestWebKitWebView.cpp:
(testWebViewCustomCharset): Wait until page is reloaded after
changing the charset.
Modified Paths
Diff
Modified: trunk/Tools/ChangeLog (188206 => 188207)
--- trunk/Tools/ChangeLog 2015-08-10 06:50:56 UTC (rev 188206)
+++ trunk/Tools/ChangeLog 2015-08-10 08:24:59 UTC (rev 188207)
@@ -1,3 +1,23 @@
+2015-08-10 Carlos Garcia Campos <[email protected]>
+
+ [GTK] Test /webkit2/WebKitWebView/submit-form is flaky
+ https://bugs.webkit.org/show_bug.cgi?id=147727
+
+ Reviewed by Sergio Villar Senin.
+
+ I think it was not this test in particular, but
+ /webkit2/WebKitWebView/custom-charset that is affecting the
+ others. This is because changing the encoding reloads the page,
+ but we don't wait for the page to be reloaded, so when the test
+ finishes and other test starts the web process is still reloading
+ the page.
+
+ * Scripts/run-gtk-tests:
+ (TestRunner): Unskip /webkit2/WebKitWebView/submit-form.
+ * TestWebKitAPI/Tests/WebKit2Gtk/TestWebKitWebView.cpp:
+ (testWebViewCustomCharset): Wait until page is reloaded after
+ changing the charset.
+
2015-08-09 Carlos Garcia Campos <[email protected]>
Unreviewed. Skip GTK+ test /webkit2/WebKitWebView/install-missing-plugins-permission-request.
Modified: trunk/Tools/Scripts/run-gtk-tests (188206 => 188207)
--- trunk/Tools/Scripts/run-gtk-tests 2015-08-10 06:50:56 UTC (rev 188206)
+++ trunk/Tools/Scripts/run-gtk-tests 2015-08-10 08:24:59 UTC (rev 188207)
@@ -63,7 +63,6 @@
SKIPPED = [
SkippedTest("WebKit2Gtk/TestUIClient", "/webkit2/WebKitWebView/mouse-target", "Test times out after r150890", 117689),
SkippedTest("WebKit2Gtk/TestCookieManager", "/webkit2/WebKitCookieManager/persistent-storage", "Test is flaky", 134580),
- SkippedTest("WebKit2Gtk/TestWebKitWebView", "/webkit2/WebKitWebView/submit-form", "Test is flaky", 147727),
SkippedTest("WebKit2Gtk/TestWebExtensions", "/webkit2/WebKitWebView/install-missing-plugins-permission-request", "Test times out", 147822),
SkippedTest("WebKit2/TestWebKit2", "WebKit2.MouseMoveAfterCrash", "Test is flaky", 85066),
SkippedTest("WebKit2/TestWebKit2", "WebKit2.NewFirstVisuallyNonEmptyLayoutForImages", "Test is flaky", 85066),
Modified: trunk/Tools/TestWebKitAPI/Tests/WebKit2Gtk/TestWebKitWebView.cpp (188206 => 188207)
--- trunk/Tools/TestWebKitAPI/Tests/WebKit2Gtk/TestWebKitWebView.cpp 2015-08-10 06:50:56 UTC (rev 188206)
+++ trunk/Tools/TestWebKitAPI/Tests/WebKit2Gtk/TestWebKitWebView.cpp 2015-08-10 08:24:59 UTC (rev 188207)
@@ -96,11 +96,16 @@
static void testWebViewCustomCharset(WebViewTest* test, gconstpointer)
{
+ test->loadHtml("<html><body>WebKitGTK+ custom encoding test</body></html>", nullptr);
g_assert(!webkit_web_view_get_custom_charset(test->m_webView));
webkit_web_view_set_custom_charset(test->m_webView, "utf8");
+ // Changing the charset reloads the page, so wait until reloaded.
+ test->waitUntilLoadFinished();
g_assert_cmpstr(webkit_web_view_get_custom_charset(test->m_webView), ==, "utf8");
- // Go back to the default charset.
- webkit_web_view_set_custom_charset(test->m_webView, 0);
+
+ // Go back to the default charset and wait until reloaded.
+ webkit_web_view_set_custom_charset(test->m_webView, nullptr);
+ test->waitUntilLoadFinished();
g_assert(!webkit_web_view_get_custom_charset(test->m_webView));
}
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes